OC.L10N.register(
    "news",
    {
    "Unread articles" : "Nelegitaj artikoloj",
    "News" : "Novaĵo",
    "Download" : "Elŝuti",
    "Close" : "Fermi",
    "Web address" : "TTT-adreso",
    "No folder" : "Neniu dosierujo",
    "Folder name" : "Dosierujnomo",
    "Username" : "Uzantonomo",
    "Password" : "Pasvorto",
    "New folder" : "Nova dosierujo",
    "Folder exists already!" : "Dosierujo jam ekzistas!",
    "Credentials" : "Aŭtentigiloj",
    "Subscribe" : "Aboni",
    "Show all articles" : "Montri ĉiujn artikolojn",
    "Move" : "Movi",
    "Share" : "Kunhavigi",
    "Share with" : "Kunhavigi kun",
    "Mark read" : "Marki kiel legita",
    "All articles" : "Ĉiuj artikoloj",
    "Starred" : "Markita",
    "Settings" : "Agordo",
    "Documentation" : "Dokumentaro",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Rename" : "Alinomigi",
    "Delete" : "Forigi",
    "Newest first" : "Pli novaj unue",
    "Oldest first" : "Malpli novaj unue",
    "Mark unread" : "Marki kiel nelegita",
    "Close details" : "Fermi detalojn",
    "by" : "de",
    "Open website" : "Malfermi TTT-ejon",
    "Not available" : "Ne disponeble",
    "right" : "dekstro",
    "left" : "maldekstro",
    "Refresh" : "Refreŝigi"
},
"nplurals=2; plural=(n != 1);");
